@@ -187,6 +187,9 @@ class TestS3Resource(unittest.TestCase):
             }
         bucket = self.s3.create_bucket(**kwargs)
         self.addCleanup(bucket.delete)
+
+        for _ in range(3):
+            bucket.wait_until_exists()
         return bucket
 
     def test_s3(self):
@@ -303,8 +306,8 @@ class TestS3Transfers(unittest.TestCase):
             Key=key)
 
     def object_exists(self, key):
-        self.client.head_object(Bucket=self.bucket_name,
-                                Key=key)
+        waiter = self.client.get_waiter('object_exists')
+        waiter.wait(Bucket=self.bucket_name, Key=key)
         return True
 
     def wait_until_object_exists(self, key_name, extra_params=None,
