@@ -10,6 +10,8 @@
 # distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
+import copy
+
 from tests import unittest
 
 from boto3.exceptions import DynamoDBOperationNotSupportedError
@@ -76,6 +78,58 @@ class TestK(unittest.TestCase):
         self.assertEqual(self.attr.between(self.value, self.value2),
                          Between(self.attr, self.value, self.value2))
 
+    def test_attribute_equality(self):
+        attr_copy = copy.deepcopy(self.attr)
+        self.assertIsNot(self.attr, attr_copy)
+        self.assertEqual(self.attr, attr_copy)
+
+    def test_eq_equality(self):
+        attr_copy = copy.deepcopy(self.attr)
+        comp = self.attr.eq(self.value)
+        comp2 = attr_copy.eq(self.value)
+        self.assertEqual(comp, comp2)
+
+    def test_eq_inequality(self):
+        attr_copy = copy.deepcopy(self.attr)
+        self.assertNotEqual(self.attr.eq(self.value),
+                            attr_copy.eq(self.value2))
+
+    def test_lt_equality(self):
+        attr_copy = copy.deepcopy(self.attr)
+        comp = self.attr.lt(self.value)
+        comp2 = attr_copy.lt(self.value)
+        self.assertEqual(comp, comp2)
+
+    def test_lte_equality(self):
+        attr_copy = copy.deepcopy(self.attr)
+        comp = self.attr.lte(self.value)
+        comp2 = attr_copy.lte(self.value)
+        self.assertEqual(comp, comp2)
+
+    def test_gt_equality(self):
+        attr_copy = copy.deepcopy(self.attr)
+        comp = self.attr.gt(self.value)
+        comp2 = attr_copy.gt(self.value)
+        self.assertEqual(comp, comp2)
+
+    def test_gte_equality(self):
+        attr_copy = copy.deepcopy(self.attr)
+        comp = self.attr.gte(self.value)
+        comp2 = attr_copy.gte(self.value)
+        self.assertEqual(comp, comp2)
+
+    def test_begins_with_equality(self):
+        attr_copy = copy.deepcopy(self.attr)
+        comp = self.attr.begins_with(self.value)
+        comp2 = attr_copy.begins_with(self.value)
+        self.assertEqual(comp, comp2)
+
+    def test_between_equality(self):
+        attr_copy = copy.deepcopy(self.attr)
+        comp = self.attr.between(self.value, self.value2)
+        comp2 = attr_copy.between(self.value, self.value2)
+        self.assertEqual(comp, comp2)
+
 
 class TestA(TestK):
     def setUp(self):
@@ -109,6 +163,48 @@ class TestA(TestK):
         self.assertEqual(self.attr.attribute_type(self.value),
                          AttributeType(self.attr, self.value))
 
+    def test_ne_equality(self):
+        attr_copy = copy.deepcopy(self.attr)
+        comp = self.attr.ne(self.value)
+        comp2 = attr_copy.ne(self.value)
+        self.assertEqual(comp, comp2)
+
+    def test_is_in_equality(self):
+        attr_copy = copy.deepcopy(self.attr)
+        comp = self.attr.is_in([self.value])
+        comp2 = attr_copy.is_in([self.value])
+        self.assertEqual(comp, comp2)
+
+    def test_exists_equality(self):
+        attr_copy = copy.deepcopy(self.attr)
+        comp = self.attr.exists()
+        comp2 = attr_copy.exists()
+        self.assertEqual(comp, comp2)
+
+    def test_not_exists_equality(self):
+        attr_copy = copy.deepcopy(self.attr)
+        comp = self.attr.not_exists()
+        comp2 = attr_copy.not_exists()
+        self.assertEqual(comp, comp2)
+
+    def test_contains_equality(self):
+        attr_copy = copy.deepcopy(self.attr)
+        comp = self.attr.contains(self.value)
+        comp2 = attr_copy.contains(self.value)
+        self.assertEqual(comp, comp2)
+
+    def test_size_equality(self):
+        attr_copy = copy.deepcopy(self.attr)
+        comp = self.attr.size()
+        comp2 = attr_copy.size()
+        self.assertEqual(comp, comp2)
+
+    def test_attribute_type_equality(self):
+        attr_copy = copy.deepcopy(self.attr)
+        comp = self.attr.attribute_type(self.value)
+        comp2 = attr_copy.attribute_type(self.value)
+        self.assertEqual(comp, comp2)
+
 
 class TestConditions(unittest.TestCase):
     def setUp(self):
